import React, { useState } from 'react';
import { Card } from 'antd';
import * as echarts from 'echarts/core';
import RangeDate from './RangeDate';
import * as dayjs from 'dayjs';
import Chart from '@/components/chart';
import { getStatIssue } from "@/service/stat";

export default React.forwardRef((props, ref) => {
  const [option, setOption] = useState({});

  const [condition, setCondition] = useState();

  React.useEffect(() => {
    if (!condition) return;

    getStatIssue(condition).then((res) => {
      setOption({
        tooltip: {
          trigger: 'axis',
          axisPointer: {
            type: 'cross',
            label: {
              backgroundColor: '#0A9071'
            }
          }
        },
        grid: {
          left: '3%',
          bottom: '3%',
          width: '92%',
          height: '90%',
          containLabel: true
        },
        xAxis: [
          {
            type: 'category',
            boundaryGap: false,
            data: res.map(x => x.name)
          }
        ],
        yAxis: [
          {
            type: 'value',
            minInterval: 1
          }
        ],
        series: [
          {
            type: 'line',
            stack: 'Total',
            smooth: true,
            lineStyle: {
              width: 0
            },
            showSymbol: false,
            areaStyle: {
              opacity: 1,
              color: new echarts.graphic.LinearGradient(0, 0, 0, 1.1, [
                {
                  offset: 0,
                  color: '#0A9071'
                },
                {
                  offset: 1,
                  color: '#FFF'
                }
              ])
            },
            emphasis: {
              focus: 'series'
            },
            data: res.map(x => x.name)
          }
        ]
      })
    })
  }, [condition]);

  const onChange = (dt, typ) => {
    if (typ == 1) {
      setCondition({
        num: 7,
        statType: 'issue_daily',
        startDate: dt[0].format('YY-MM-DD'),
        endDate: dt[1].format('YY-MM-DD'),
      })
    } else if (typ == 2) {
      setCondition({
        num: dt[0].daysInMonth(),
        statType: 'issue_daily',
        startDate: dt[0].format('YY-MM-DD'),
        endDate: dt[1].format('YY-MM-DD'),
      })
    } else if (typ == 3) {
      setCondition({
        num: 365,
        statType: 'issue_daily',
        startDate: dt[0].format('YY-MM-DD'),
        endDate: dt[1].format('YY-MM-DD'),
      })
    }

    console.log('dt天数', dt[0].format('MM-DD'));
    // console.log('dt,typ', dt, typ);
  }

  return (
    <Card title="上报统计" extra={<RangeDate onChange={onChange} />}>
      <Chart option={option} style={props.style}></Chart>
    </Card>
  )
});