import React, { useState } from 'react';
import { Card, Select } from 'antd';
import * as echarts from 'echarts/core';
import Chart from '@/components/chart';
import { getStatEscalation } from "@/service/stat";
import { getSysOrg } from "@/service/sysorg";

export default (props) => {
  const [option, setOption] = useState({});
  // const [id, setId] = useState({});
  const [orgList, setOrgList] = useState([]);
  const [orgId, setOrgId] = useState();
  console.log('orgId', orgId);

  React.useEffect(() => {
    getSysOrg({ pageSize: 500 }).then((res) => {
      setOrgList(res.records || [])
    })
  }, []);

  React.useEffect(() => {
    getStatEscalation({ orgId: orgId }).then((res) => {
      setOption({
        tooltip: {
          trigger: 'axis',
          axisPointer: {
            type: 'cross',
            label: {
              backgroundColor: '#F772D1'
            }
          }
        },
        grid: {
          left: '3%',
          bottom: '3%',
          width: '90%',
          height: '90%',
          containLabel: true
        },
        xAxis: [
          {
            type: 'category',
            data: res.map(x => x.name),
            boundaryGap: true,
            name: '状态',
            axisTick: {
              alignWithLabel: true,
            }
          }
        ],
        yAxis: [
          {
            type: 'value',
            minInterval: 1,
            name: '交办次数'
          }
        ],
        series: [
          {
            type: 'bar',
            barWidth: '15%',
            itemStyle: {
              color: new echarts.graphic.LinearGradient(0, 0, 0, 1, [
                { offset: 0, color: '#F772D1' },
                { offset: 0.5, color: '#C872F2' },
                { offset: 1, color: '#E5BEF8' }
              ])
            },
            data: res.map(x => x.value),
          }
        ]
      })
    })
  }, [orgId]);

  return (
    <Card
      title="交办统计"
      extra={
        <Select style={{ width: "200px" }} placeholder="请选择单位" value={orgId} onChange={e => setOrgId(e)}>
          {
            orgList.map((item) => (
              <Select.Option key={item.orgId} value={item.orgId}>
                {item.name}
              </Select.Option>
            )
            )
          }
        </Select>
      }
    >
      <Chart option={option} style={props.style}></Chart>
    </Card>
  )
}