import React from 'react';
import dayjs from 'dayjs';
import { Card, Steps } from 'antd';
import useBool from '@/utils/hooks/useBool';
import { getTaIssueProcess } from '@/service/taissueprocess';

const fmDt = dt => !dt ? '-' : dayjs(dt).format('YYYY-MM-DD');

export default (props) => {

  const { issueId } = props;

  const [loading, startLoading, stopLoading] = useBool();
  const [items, setItems] = React.useState([
    { title: '待交办' },
    { title: '处理中' },
    { title: '已办结' },
  ]);

  const [current, setCurrent] = React.useState(0);

  React.useEffect(() => {
    if (issueId) {
      startLoading();
      getTaIssueProcess({ pageSize: 100, issueId }).then(res => {
        stopLoading();
        const records = res.records || [];

        const startRec = records.filter(x => x.processNode == 'start')[0];
        const assignedRec = records.filter(x => x.processNode == 'assigned')[0];
        const endRec = records.filter(x => x.processNode == 'end')[0];

        setItems([
          { title: '待交办', description: fmDt(startRec?.createDate) },
          { title: '处理中', description: fmDt(assignedRec?.createDate) },
          { title: '已办结', description: fmDt(endRec?.createDate) },
        ]);

        if (endRec) {
          setCurrent(2);
        } else if (assignedRec) {
          setCurrent(1);
        } else {
          setCurrent(0);
        }

      }).catch(() => {
        stopLoading();
      });
    }
  }, [issueId]);

  return (
    <Card loading={loading}>
      <Steps current={current} items={items}/>
    </Card>
  )
}
